#!/bin/sh
# 
# Copyright 1999 American Power Conversion, All Rights Reserved
#
# Description: This file is used to remove PowerChute Plus for Unix from
#              your system
#
# Usage: ./Remove.sh will execute the script
#
# Revision History:
#  msamson 11Mar99 Port to Linux
#  msamson 01Apr99 Made some modification for Linux - use 'ps aux' instead of
#                  'ps -e', also 'echo -e' instead of 'echo'.  
#  msamson 01Apr99 Modified remove startup file for Linux to be 
#                  /etc/rc.d/rc2.d/S98upsd
#  msamson 01Apr99 Added code to make sure /etc/inittab is cleaned up for 
#                  Linux
#  msamson 02Apr99 Made minor syntax corrections for Linux
#  twenisch21Apr99 Changed for Linux so that all files created by
#                  new Linux startup code are removed.
#  twenisch22Apr99 Changed ps aux to ps ax
#  twenisch05May99 Remove will only accept y or n responses
#  msamson 17May99 No longer call KillPCPClients. Clients are killed when
#                  killpc.sh is executed. Also added code to remove 
#                  APC_REPOSITORY if it is empty.
#  msamson 17May99 Used echo " " to stop script from printing itself
#  msamson 21May99 Used rm -rf $RMDIR instead of rmdir $RMDIR.  This ensures
#                  that the powerchute directory will be removed
#  
# 
#

DEFAULT="pcp_unix.apc"
THIS=${1:-$DEFAULT}
INST_UI_ONLY=
#--------------------------------------------------------------------------
# Do not change definitions of TRUE=0 FALSE=1, or && || shell logic fails
#--------------------------------------------------------------------------
TRUE=0
FALSE=1

PATH=/bin:/usr/bin:/sbin:/usr/sbin:/etc:/usr/ccs/bin
export PATH

RemovePcpStartUpFiles() {
	echo "Removing Startup Files."
	. ./what_os.sh
	case "$OS" in
		$SCO)
			rm -f /etc/rc.d/7/upsd.boot
			rm -r /etc/rc.APCupsd
			;;
		$UWARE7)
			rm -f /etc/rc2.d/S98upsd.boot
			rm -r /etc/rc.APCupsd
			;;
		$SOLARIS2X|$SOLARIS2X86|$SGI|$NCR|$UWARE1|$UWARE2|$OLIV|$USYS|$INT)
			rm -f /etc/rc2.d/S*upsd
			;;
		$AIX|$HPUX9|$HPUX10)
			rm -r /etc/rc.APCupsd
			cp /etc/inittab /etc/inittab.bak2
			if [ -r /etc/inittab.bak2 ]
			then
				rm -f /etc/inittab
				sed '/POWERCHUTE/d' /etc/inittab.bak2 > /etc/inittab
			else
				echo "Error writing /etc/inittab.bak2. Quitting"
			fi
			;;
		$SUNOS4) 
			rm -f /etc/rc.APCupsd
			cp /etc/rc.local /etc/rc.local.bak2
			if [ -r /etc/rc.local.bak2 ]
			then
				rm -f /etc/rc.local
				sed '/POWERCHUTE/d' /etc/rc.local.bak2 > /etc/rc.local
			else
				echo "Error writing /etc/rc.local.bak2. Quitting"
			fi
			;;
		 $NCR)
                        if [ -r PROTECT_INIT_1 ]
                        then
                          cp /etc/inittab /etc/inittab.bak2
                          if [ -r /etc/inittab.bak2 ]
                          then
                                rm -f /etc/inittab
                                sed '/POWERCHUTE/d' /etc/inittab.bak2 > /etc/inittab
                          else
                                echo "Error writing /etc/inittab.bak2. Quitting"
                          fi
  		          if [ -r /etc/conf/init.d/powerchute ]
			  then
				rm -f /etc/conf/init.d/powerchute
			   fi
                        else
                          rm -f /etc/rc2.d/S*upsd
                        fi
                        ;;
		$ALPHAOSF) 
                          rm -f /sbin/rc3.d/S*upsd
                        ;;
		$LINUX)
			  for RUN_LEVEL in 2 3 4 5;
			  do
			    rm -f /etc/rc.d/rc$RUN_LEVEL.d/S*upsd
			  done
			  rm -f /etc/rc.d/init.d/upsd
		  ;;
	esac
	echo "Done."
}

RemovePcpShutdownFiles() { 

	echo "Cleaning Shutdown Files."
	. ./what_os.sh
	case "$OS" in
		$SOLARIS2X|$SOLARIS2X86|$UWARE1|$UWARE2|$OLIV|$USYS|$NCR|$ALPHAOSF|$UWARE7)
			mv /sbin/rc0 /sbin/rc0.bak2
			sed '/POWERCHUTE/ d' /sbin/rc0.bak2 > /sbin/rc0 
			chmod u+x /sbin/rc0
			;;
		$SGI|$INT|$SCO)
			mv /etc/rc0 /etc/rc0.bak2
			sed '/POWERCHUTE/ d' /etc/rc0.bak2 > /etc/rc0 
			chmod u+x /etc/rc0
			;;
		$AIX)
 		      if [ -r /usr/sbin/shutdown ]
                      then
                        SHUTDOWN_FILE=/usr/sbin/shutdown
                      else
                        SHUTDOWN_FILE=/etc/shutdown
                      fi
                      mv $SHUTDOWN_FILE $SHUTDOWN_FILE.bak2
                      sed '/POWERCHUTE/ d' $SHUTDOWN_FILE.bak2 > $SHUTDOWN_FILE
                      chmod u+x $SHUTDOWN_FILE
			;;
		$HPUX9)
			cp ./sysfiles.bak/reboot.bak /etc/reboot
			chmod u+x /etc/reboot
			;;
		$HPUX10)
			cp ./sysfiles.bak/reboot.bak /sbin/reboot
			chmod u+x /sbin/reboot
			;;
		$SUNOS4)
			mv /usr/etc/halt.exe /usr/etc/halt
			chmod u+x /usr/etc/halt
			;;
		$NCR)
			rm /etc/rc0.d/K*upsd
			;;
		$LINUX)
			mv /etc/rc.d/init.d/halt /etc/rc.d/init.d/halt.bak2
			sed '/POWERCHUTE/ d' /etc/rc.d/init.d/halt.bak2 >  /etc/rc.d/init.d/halt 
			chmod u+x  /etc/rc.d/init.d/halt
			;;
	esac
	echo "Done."
}

	

KillPCPClients() {
# -----------------------------------------------------------------------
# I could use awk's system() here, but I trust the portablity of /bin/sh
# more than that of awk
# -----------------------------------------------------------------------
        . ./what_os.sh
	if [ "$OS" = "LINUX" ]
	then
	    ps ax | awk '/pwrchu/ {print $1}' > tmp.pid
	else   
	    ps -e | awk '/pwrchu/ {print $1}' > tmp.pid
	fi

	if [ -s tmp.pid ]   #Exists and file size greater than 0
	then
		set `cat tmp.pid`
		while [ ! -z "$1" ]
		do
			echo "killing powerchute client with pid = $1"
			kill -9 $1
			echo "Done."
			shift
		done
	fi
	
	rm -f tmp.pid
}

RemovePcpHiddenFiles() {
	rm -f ./.upsd*
}

OkToRemove() {
    exit_script=$TRUE
    echo " "
    echo " "
    echo " "
    echo " ****************  WARNING!!! ***************** "
    echo " "
    echo " All files and directories starting at `pwd` will be "
    echo " removed recursively.  Do NOT continue execution of this script"
    echo " unless `pwd` is a separate directory containing only APC"
    echo " software and there are no user or other significant directories"
    echo " beneath `pwd`."
    echo " "
    echo " "
    beep
    continue_loop_flag=$TRUE
    while [ $continue_loop_flag -eq $TRUE ]
    do
	echo " Do you wish to continue removing the `pwd` directory (y/n)?"
	. ./what_os.sh
	if [ "$OS" = "$LINUX" ]
	then
	    echo -e " \\c" 
	else
	    echo " \\c"
	fi
 
	read response
	if [ -n "$response" ]
	then
	case "$response" in
	    [Yy]*)
		continue_loop_flag=$FALSE
		exit_script=$FALSE
		REMOVE_FAILED=$FALSE
		;;
	    [Nn]*)
		exit
		;;
	    *)
		;;
	esac
	fi
	done   
	return $exit_script
}

beep() {
     
     . ./what_os.sh
    if [ "$OS" = "$LINUX" ]
    then
        echo -e "\a\\c"
    else
        echo "^G\\c"
    fi

}

#---------------------------------------------------------------------------
#      Start
#---------------------------------------------------------------------------

APC_REPOSITORY=/etc/apc_repository
RMDIR=`pwd`
REMOVE_FAILED=$TRUE

OkToRemove 

if [ $REMOVE_FAILED = $TRUE ]
then
  exit
fi


if [ ! -r ./what_os.sh ]
then
	echo "You must be in the install directory in order to invoke this script"
	exit
fi

if [ ! -r ./_upsd ]
then
	INST_UI_ONLY=$TRUE
else
	INST_UI_ONLY=$FALSE
fi

cd $APC_REPOSITORY
if [ -r ./*.apc ]
then
	set `ls *.apc`
	if [ $1 = $THIS ]
	then
		set `cat $1`
		PROD=$1
		cd $RMDIR
		. ./what_os.sh
		case "$PROD" in
		"pcp_unix.apc")
			./killpc.sh
			RemovePcpHiddenFiles;
			if [ $INST_UI_ONLY -eq $FALSE ]
			then
				RemovePcpStartUpFiles;
				RemovePcpShutdownFiles;
			fi
			;;
		*)
			echo "Unknown product in $THIS! Qutting."
			exit
			;;
		esac
		echo "Removing $PROD from $APC_REPOSITORY"
		rm $APC_REPOSITORY/$THIS
		DIR_CONTENTS=`ls $APC_REPOSITORY`
		if [ -z "$DIR_CONTENTS" ]
		then
		    echo "Removing $APC_REPOSITORY"
		    rm -fr $APC_REPOSITORY
		fi
		echo "Removing contents of install directory"
		case "$OS" in
		$SCO|$INT|$UWARE7|$LINUX)
			chmod ugo+rw *
			;;
		*)
			chmod -R ugo+rw *
			;;
		esac
		rm -rf *

        # remove .tmp directory
        if [ -d $RMDIR/.tmp ]
        then
             cd $RMDIR/.tmp
             rm -rf *
             cd $RMDIR
             rmdir .tmp
        fi
		cd /
		rm -rf $RMDIR
		echo "Done."
	else
		echo "Unable to determine product to be removed!"
		exit
	fi
else
	echo "Unable to determine installed product!"
	echo "Exiting."
fi


