#!/bin/sh
#
#----------------------------------------------------------------------
#	
# Copyright 1999 American Power Conversion, Inc.
#
# DESCRIPTION: dialpager.sh - Dials a Pager through a modem
#
#----------------------------------------------------------------------
#
# Args:
#	$1 - Script Name
#	$2 - Port Name
#	$3 - Baud Rate
#
#----------------------------------------------------------------------


PATH=/bin:/usr/bin:/sbin:/usr/sbin:/etc:/usr/ccs/bin
export PATH

PWRCHUTE=/usr/lib/powerchute
TMPDIR=$PWRCHUTE/.tmp
export TMPDIR
export PWRCHUTE

script=$1
port=$2
baud=$3


###################################################################### 
# Name: DialLinuxPager
# 
# Description: This function is responsible for reading modem commands
#              from a paging script build by pwrchute and sending each
#              modem command to the cu command. This function also 
#              sleeps a specified delay (obtained from paging script) 
#              before sending each modem command to the cu command.
#
######################################################################

DialLinuxPager(){

# we must pass awk all needed variables to awk script
awk -v tmpfile=$tmpfile -v baud=$baud -v port=$port -v tmpcommand=$tmpcommand ' 
   # while there are still lines to get from paging tmpfile
   BEGIN { while (getline < tmpfile >  0 ) {
	        # set pagecommand to line in file
		pagecommand=$0
	  	
		# need to substitute all semicolons in pagecommand with 
                # \; so that echo will interpret semicolons properly 
		gsub(/;/,"\\;",$pagecommand);
		
		# echo pager command to tmpcommand file
		system("echo "$pagecommand" > "tmpcommand"")
		
		# execute cu for each command using tmpcommand file
		system("cu -s"baud" -l "port" < "tmpcommand" > /dev/null 2>/dev/null")
	  	
		# get delay value and sleep 
		delay=getline < tmpfile
		if($delay> 0){
			system("sleep "$delay"")
	  	}
       	    }
          }'
}


modemlock=$TMPDIR/modemlock
tmpcommand=$TMPDIR/$$.command
tmpfile=$TMPDIR/$$.page

. ./what_os.sh

# if modemlock exists, then exit
if [ -r $modemlock ]
then
    exit
fi

touch $modemlock
cp $script $tmpfile

# this is no longer needed on LINUX since we are calling cu 
# multiple times
if [ "$OS" != "$LINUX" ]
then
    echo "~." >> $tmpfile
fi

case "$OS" in
	$HPUX|$AIX)
        cu -s$baud -ml $port < $tmpfile > /dev/null 2>/dev/null
	;;
	$UWARE7)
        cu -l $port < $tmpfile 2>/dev/null
        ;;
 	$LINUX)
	DialLinuxPager;
	;;
    *)
        cu -s$baud -l $port < $tmpfile /dev/null 2>/dev/null
	;;
esac


# removal of tmp files - make sure these files are located in the powerchute
# tmp directory before removal 

MATCH=`expr match $tmpfile $TMPDIR`
if [ $MATCH -ne 0 ]
	then
   	rm -f $tmpfile
fi

MATCH=`expr match $script $TMPDIR`
if [ $MATCH -ne 0 ]
	then
   	rm -f $script
fi

MATCH=`expr match $tmpcommand $TMPDIR`
if [ $MATCH -ne 0 ]
	then
   	rm -f $tmpcommand
fi

# clear modem lock 
if [ -r $modemlock ]
then
    rm -f $modemlock
fi








